@@ -1,4 +1,8 @@
 #!/usr/bin/python
+#
+# SPDX-License-Identifier: GPL-2.0-only
+# (c) 2023 Gerd Hoffmann
+#
 """
 efi device path decoder
 
@@ -23,15 +27,28 @@ class DevicePathElem:
             self.data = data[ 4 : size ]
 
     def set_ipv4(self):
-        self.devtype = 0x03
-        self.subtype = 0x0c
+        self.devtype = 0x03	# msg
+        self.subtype = 0x0c	# ipv4
         self.data    = bytes(23) # use dhcp
 
     def set_uri(self, uri):
-        self.devtype = 0x03
-        self.subtype = 0x18
+        self.devtype = 0x03	# msg
+        self.subtype = 0x18	# uri
         self.data    = str(uri).encode()
 
+    def set_filepath(self, filepath):
+        self.devtype = 0x04	# media
+        self.subtype = 0x04	# filepath
+        self.data    = bytes(ucs16.from_string(str(filepath)))
+
+    def set_gpt(self, pnr, poff, plen, guid):
+        self.devtype = 0x04	# media
+        self.subtype = 0x01	# hard drive
+        self.data = b''
+        self.data += struct.pack('=LQQ', pnr, poff, plen)
+        self.data += guids.parse_str(guid).bytes_le
+        self.data += struct.pack('=BB', 0x02, 0x02)
+
     def fmt_hw(self):
         if self.subtype == 0x01:
             (func, dev) = struct.unpack_from('=BB', self.data)
@@ -72,6 +89,10 @@ class DevicePathElem:
         if self.subtype == 0x12:
             (port, mul, lun) = struct.unpack_from('=HHH', self.data)
             return f'SATA(port={port})'
+        if self.subtype == 0x13:
+            (proto,login,lun,tag) = struct.unpack_from('=HHQH', self.data)
+            target = self.data[ 14: ].decode()
+            return f'ISCSI({target})'
         if self.subtype == 0x18:
             return f'URI({self.data.decode()})'
         if self.subtype == 0x1f:
@@ -111,6 +132,21 @@ class DevicePathElem:
             return self.fmt_media()
         return f'Unknown(type=0x{self.devtype:x},subtype=0x{self.subtype:x})'
 
+    def __eq__(self, other):
+        if self.devtype != other.devtype:
+            return False
+        if self.subtype != other.subtype:
+            return False
+
+        if self.devtype == 0x04 and self.subtype == 0x04:
+            # FilePath -> compare case-insensitive
+            p1 = str(ucs16.from_ucs16(self.data)).lower()
+            p2 = str(ucs16.from_ucs16(other.data)).lower()
+            return p1 == p2
+
+        return self.data == other.data
+
+
 class DevicePath(collections.UserList):
     """ class reprsenting an efi device path """
 
@@ -133,6 +169,14 @@ class DevicePath(collections.UserList):
         path.append(elem)
         return path
 
+    @staticmethod
+    def filepath(filepath):
+        path = DevicePath()
+        elem = DevicePathElem()
+        elem.set_filepath(filepath)
+        path.append(elem)
+        return path
+
     def __bytes__(self):
         blob = b''
         for elem in list(self):
@@ -142,3 +186,13 @@ class DevicePath(collections.UserList):
 
     def __str__(self):
         return "/".join(map(str, list(self)))
+
+    def __eq__(self, other):
+        if len(self) != len(other):
+            return False
+        idx = 0
+        while idx < len(self):
+            if self[idx] != other[idx]:
+                return False
+            idx += 1
+        return True
