@@ -137,7 +137,7 @@ ascii_names = ('Lang', 'PlatformLang', 'SbatLevel')
 blist_names = ('BootOrder', 'BootNext')
 dpath_names = ('ConIn', 'ConOut', 'ErrOut')
 
-initial_ts  = datetime.datetime(2010, 1, 1)
+initial_ts  = datetime.datetime(2010, 1, 1, tzinfo = datetime.timezone.utc)
 
 ##################################################################################################
 
@@ -145,6 +145,7 @@ initial_ts  = datetime.datetime(2010, 1, 1)
 class EfiVar:
     """  class for efi variables """
 
+    # pylint: disable=too-many-positional-arguments
     def __init__(self, name,
                  guid = None,
                  attr = None,
@@ -189,7 +190,8 @@ class EfiVar:
         if year:
             self.time = datetime.datetime(year, month, day,
                                           hour, minute, second,
-                                          int(ns / 1000))
+                                          int(ns / 1000),
+                                          tzinfo = datetime.timezone.utc)
         else:
             self.time = None
 
@@ -216,7 +218,7 @@ class EfiVar:
         if not self.attr & EFI_VARIABLE_TIME_BASED_AUTHENTICATED_WRITE_ACCESS:
             return
         if ts is None:
-            ts = datetime.datetime.now()
+            ts = datetime.datetime.now(tz = datetime.timezone.utc)
         if self.time is None or self.time < ts:
             self.time = ts
 
@@ -451,22 +453,28 @@ class EfiVarList(collections.UserDict):
         self.set_bool('CustomMode', False)
 
     def enroll_platform_with_cert(self, cert,
-                                  guid = guids.OvmfEnrollDefaultKeys):
+                                  guid = guids.OvmfEnrollDefaultKeys,
+                                  ms_kek = 'all'):
         self.add_cert('PK', guid, cert, True)
         self.add_cert('KEK', guid, cert, True)
-        self.add_cert('KEK', guids.MicrosoftVendor, certs.MS_KEK, False)
+        if ms_kek in ('2011', 'all'):
+            self.add_cert('KEK', guids.MicrosoftVendor, certs.MS_KEK_2011, False)
+        if ms_kek in ('2023', 'all'):
+            self.add_cert('KEK', guids.MicrosoftVendor, certs.MS_KEK_2023, False)
         self.add_dummy_dbx(guids.OvmfEnrollDefaultKeys)
 
-    def enroll_platform_redhat(self):
-        self.enroll_platform_with_cert(certs.REDHAT_PK)
+    def enroll_platform_redhat(self, ms_kek = 'all'):
+        self.enroll_platform_with_cert(certs.REDHAT_PK, ms_kek = ms_kek)
 
-    def enroll_platform_generate(self, name):
+    def enroll_platform_generate(self, name, ms_kek = 'all'):
         pk = certs.pk_generate(cn = name)
-        self.enroll_platform_with_cert(pk.name)
+        self.enroll_platform_with_cert(pk.name, ms_kek = ms_kek)
 
     def add_microsoft_keys(self):
-        self.add_cert('db', guids.MicrosoftVendor, certs.MS_WIN, False)
-        self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD, False)
+        self.add_cert('db', guids.MicrosoftVendor, certs.MS_WIN_2011, False)
+        self.add_cert('db', guids.MicrosoftVendor, certs.MS_WIN_2023, False)
+        self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD_2011, False)
+        self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD_2023, False)
 
     def add_distro_keys(self, distro):
         certlist = certs.DISTRO_CA.get(distro).get('certs')
