@@ -11,6 +11,7 @@ import logging
 import pkg_resources
 
 from cryptography import x509
+from cryptography.exceptions import InvalidSignature
 from cryptography.hazmat.primitives.serialization import pkcs7
 
 from virt.firmware.efi import guids
@@ -128,6 +129,8 @@ def is_cert_issuer_in_sigdb(cert, variable):
 #
 # The pkcs7 signature itself is NOT verified.
 #
+# This requires cryptography_major >= 40.
+#
 def pe_check_cert(siglist, variable):
     if not variable:
         return None
@@ -141,6 +144,8 @@ def pe_check_cert(siglist, variable):
                         return sigcert
                     except (ValueError, TypeError):
                         pass
+                    except InvalidSignature:
+                        pass
                     if sigcert == dbcert.x509:
                         return sigcert
     return None
